% Sh = computeSh(bHD, sIFO, noiseTotal)
%
% IFO sensitivity curve
%  bHD is the homodyne readout vector (1x2xNf)
%  sIFO is the IFO signal vector (2x1xNf)
%  noiseTotal is the quantum noise (see noiseInputFC)
%
% Examples:
%   [nTotal, ~, ~, ~, ~, ifo] = noiseInputFC(f, sqzDB, lengthFC, ...
%     lossFC, lossInj, lossRO, mmSqzFC, mmSqzLO, mmPhi, phiRMS, xRMS)
%   Sh = computeSh(ifo.bHD, ifo.sIFO, nTotal);
%   
%   s = load('thermal_noise');
%   Sh_therm = logspline(s.fThermal, s.nThermal, f);
%   Sh_total = sqrt(Sh_therm.^2 + Sh.^2);
%
%   rangeInfo = computeRange(f, Sh_total)
%   fprintf(1, 'Baseline range %.0f MPc\n', rangeInfo.effr0ns);

function Sh = computeSh(bHD, sIFO, noiseTotal)

  Sh = sqrt(noiseTotal ./ squeeze(sum(abs(getProdTF(bHD, sIFO)).^2, 2)));

end
